pub struct ResolvedManifest {
pub manifest: ImageManifest,
pub manifest_descriptor: Descriptor,
pub source_index: Option<(ImageIndex, Descriptor)>,
}Expand description
Result of resolving a manifest for a specific platform.
Contains the resolved manifest along with its descriptor, and optionally the image index (manifest list) it was resolved from with its descriptor.
Fields
manifest: ImageManifestThe resolved image manifest
manifest_descriptor: DescriptorThe descriptor of the manifest (includes digest, size, media type)
source_index: Option<(ImageIndex, Descriptor)>The image index this manifest was resolved from, if any (with its descriptor)